@@ -1,5 +1,7 @@
 import os
 import json
+from copy import deepcopy
+
 from flask import Blueprint, request, render_template, send_from_directory, current_app
 from flask_restful import (Api as restful_Api, abort as flask_abort,
                            Resource as flask_Resource)
@@ -466,6 +468,26 @@ class Schema(dict):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
+        super_classes = [
+            schema for schema_name, schema in REGISTRY_SCHEMA.items()
+            if schema_name != self.__class__.__name__ and isinstance(self, schema)
+        ]
+        for super_class in super_classes:
+            if not hasattr(super_class, 'type'):
+                raise TypeError("You can inherit only schema of type 'object'")
+            if super_class.type != 'object':
+                raise TypeError("You can inherit only schema of type 'object'")
+            if self.type != super_class.type:
+                raise TypeError(f"You can't add type to '{self.__class__.__name__}'" +
+                                 f"because it inherits of type of '{super_class.__name__}'")
+            if super_class.properties:
+                if self.properties:
+                    self.properties.update(deepcopy(super_class.properties))
+
+            if hasattr(super_class, 'required'):
+                if hasattr(self, 'required'):
+                    self.required += super_class.required
+
         if self.properties:
             for k, v in kwargs.items():
                 if k not in self.properties:
@@ -478,8 +500,18 @@ class Schema(dict):
                 else:
                     prop = self.properties[k]
 
+                type_ = None
                 if 'type' in prop:
-                    self.check_type(prop['type'], k, v)
+                    type_ = prop['type']
+                self.check_type(type_, k, v)
+
+                if 'enum' in prop:
+                    if type(prop['enum']) not in [set, list, tuple]:
+                        raise TypeError(f"'enum' is must be 'list', 'set' or 'tuple', but was {type(prop['enum'])}")
+                    for item in list(prop['enum']):
+                        self.check_enum_type(type_, item)
+                    if v not in prop['enum']:
+                        raise ValueError(f"{k} must have {' or '.join(prop['enum'])} but have {v}")
                 self[k] = v
 
         if hasattr(self, 'required'):
@@ -489,15 +521,29 @@ class Schema(dict):
 
     @staticmethod
     def check_type(type_, key, value):
-        if type_ == 'integer' and not isinstance(value, int):
-            raise ValueError('The attribute "{0}" must be an int, but was "{1}"'.format(key, type(value)))
-        if type_ == 'number' and not isinstance(value, int) and not isinstance(value, float):
-            raise ValueError(
-                'The attribute "{0}" must be an int or float, but was "{1}"'.format(key, type(value)))
-        if type_ == 'string' and not isinstance(value, str):
-            raise ValueError('The attribute "{0}" must be a string, but was "{1}"'.format(key, type(value)))
-        if type_ == 'boolean' and not isinstance(value, bool):
-            raise ValueError('The attribute "{0}" must be an int, but was "{1}"'.format(key, type(value)))
+        if type_:
+            if type_ == 'integer' and not isinstance(value, int):
+                raise ValueError(f'The attribute "{key}" must be an int, but was "{type(value)}"')
+            if type_ == 'number' and not isinstance(value, int) and not isinstance(value, float):
+                raise ValueError(
+                    f'The attribute "{key}" must be an int or float, but was "{type(value)}"')
+            if type_ == 'string' and not isinstance(value, str):
+                raise ValueError(f'The attribute "{key}" must be a string, but was "{type(value)}"')
+            if type_ == 'boolean' and not isinstance(value, bool):
+                raise ValueError(f'The attribute "{key}" must be an int, but was "{type(value)}"')
+
+    @staticmethod
+    def check_enum_type(type_, value):
+        if type_:
+            if type_ == 'integer' and not isinstance(value, int):
+                raise ValueError(f'The enum "{value}" must be an int, but was "{type(value)}"')
+            if type_ == 'number' and not isinstance(value, int) and not isinstance(value, float):
+                raise ValueError(
+                    f'The enum "{value}" must be an int or float, but was "{type(value)}"')
+            if type_ == 'string' and not isinstance(value, str):
+                raise ValueError(f'The enum "{value}" must be a string, but was "{type(value)}"')
+            if type_ == 'boolean' and not isinstance(value, bool):
+                raise ValueError(f'The enum "{value}" must be an int, but was "{type(value)}"')
 
     @classmethod
     def reference(cls):
